pub enum VadError {
InvalidSampleRate(u32),
InvalidFrameSize {
got: usize,
expected: usize,
},
BackendError(String),
}Expand description
Errors that can occur during voice activity detection.
Variants
InvalidSampleRate(u32)
The provided sample rate is not supported by the backend.
InvalidFrameSize
The provided frame size does not match the expected size for the backend.
BackendError(String)
An error originating from the underlying VAD backend.